# Hammal

Install:

```bash
$ pip install add-header-mv
```

Usage:

```bash
$ add-header-mv <arg1> <arg2> <arg3>
```

`arg1` is file postfix, maybe `".py"` or `".java"`.

`arg2` is what you want to add to head of file, maybe `import os` or `package what.you.want;`.

`arg3` is target dir name, maybe `../otherDir` or `/User/xxx/doc`.
